import requests


class Verifications:
    def __init__(self, node):
        self.node = node

    def get(self, app, context_id='', **kwargs):
        params = (
            ('timestamp', kwargs.get('timestamp')),
            ('signed', kwargs.get('signed')),
            ('count_only', kwargs.get('count_only'))
        )
        response = requests.get(f'{self.node.url}/verifications/{app}/{context_id}', params=params)
        res = response.json()
        self.node.check_error(res)
        if res.get('data').get('count') and kwargs.get('count_only'):
            return res.get('data').get('count')
        return res.get('data')



import requests

from . import users, operations, verifications, testblocks, apps


class Node:
    def __init__(self, url='http://node.brightid.org/brightid/v5'):
        self.url = url
        self.users = users.Users(self)
        self.operations = operations.Operations(self)
        self.verifications = verifications.Verifications(self)
        self.testblocks = testblocks.Testblocks(self)
        self.apps = apps.Apps(self)
    def ip(self):
        response = requests.get(f'{self.url}/ip')
        res = response.json()
        self.check_error(res)
        return res.get('data').get('ip')

    def state(self):
        response = requests.get(f'{self.url}/state')
        res = response.json()
        self.check_error(res)
        return res.get('data')

    def check_error(self, res):
        if res.get('error'):
            raise RuntimeError(res.get('errorMessage'))


import requests


class Apps:
    def __init__(self, node):
        self.node = node

    def get(self, app=''):
        response = requests.get(f'{self.node.url}/apps/{app}')
        res = response.json()
        self.node.check_error(res)
        return res.get('data').get('apps') or res.get('data')



import ed25519
import json
import base64
import pyqrcode


def create_deep_link(context, context_id, url='http://node.brightid.org', schema='https'):
    url = url.replace('/', '%2f')
    if schema == 'brightid':
        deep_link = f'brightid://link-verification/{url}/{context}/{context_id}'
    else:
        deep_link = f'https://app.brightid.org/link-verification/{url}/{context}/{context_id}/'
    return deep_link


def create_qr(deep_link, scale=8):
    qr = pyqrcode.create(deep_link)
    return qr.png_as_base64_str(scale=scale)


def sign(op, private):
    signing_key = ed25519.SigningKey(base64.b64decode(private))
    message = json.dumps(op, sort_keys=True,
                         separators=(',', ':')).encode('ascii')
    sig = signing_key.sign(message)
    sig = base64.b64encode(sig).decode('ascii')
    return sig


def create_bright_id():
    private, public = ed25519.create_keypair()
    private = base64.b64encode(private.to_bytes()).decode('ascii')
    public = base64.b64encode(public.to_bytes()).decode('ascii')
    id = public.strip('=').replace('/', '_').replace('+', '-')
    return {
        'id': id,
        'private': private,
        'public': public
    }



import requests


class Operations:
    def __init__(self, node):
        self.node = node

    def post(self, op):
        response = requests.post(
            f'{self.node.url}/operations', json=op)
        res = response.json()
        self.node.check_error(res)
        return res.get('data').get('hash')

    def get(self, hash):
        response = requests.get(
            f'{self.node.url}/operations/{hash}')
        res = response.json()
        self.node.check_error(res)
        return res.get('data')



import requests


class Testblocks:
    def __init__(self, node):
        self.node = node

    def put(self, app, action, context_id, testing_key):
        params = (
            ('testingKey', testing_key),
        )
        response = requests.put(
            f'{self.node.url}/testblocks/{app}/{action}/{context_id}', params=params)
        if not response.ok:
            res = response.json()
            self.node.check_error(res)

    def delete(self, app, action, context_id, testing_key):
        params = (
            ('testingKey', testing_key),
        )
        response = requests.delete(
            f'{self.node.url}/testblocks/{app}/{action}/{context_id}', params=params)
        if not response.ok:
            res = response.json()
            self.node.check_error(res)



import requests

class Users:
    def __init__(self, node):
        self.node = node

    def get(self, user):
        response = requests.get(
            f'{self.node.url}/users/{user}')
        res = response.json()
        self.node.check_error(res)
        return res.get('data')

    def verifications(self, user):
        response = requests.get(
            f'{self.node.url}/users/{user}/verifications')
        res = response.json()
        self.node.check_error(res)
        return res.get('data').get('verifications')

    def connections(self, user, direction):
        response = requests.get(
            f'{self.node.url}/users/{user}/connections/{direction}')
        res = response.json()
        self.node.check_error(res)
        return res.get('data').get('connections')

    def profile(self, user, requestor):
        response = requests.get(
            f'{self.node.url}/users/{user}/profile/{requestor}')
        res = response.json()
        self.node.check_error(res)
        return res.get('data')



from distutils.core import setup
setup(
  name = 'python_brightid',
  packages = ['brightid'],
  version = '1.1.5',
  license='MIT',
  description = 'SDK for integrating with BrightId!',
  author = 'Pooya Fekri',
  author_email = 'pooyafekri79@gmail.com',
  url = 'https://github.com/PooyaFekri/python-brightid',
  download_url = 'https://github.com/PooyaFekri/python-brightid/archive/main.zip',
  keywords = ['Brightid'],
  install_requires=[
          'requests',
          'ed25519',
          'pyqrcode',
          'pypng'
      ],
  classifiers=[  # Optional
    # How mature is this project? Common values are
    #   3 - Alpha
    #   4 - Beta
    #   5 - Production/Stable
    'Development Status :: 4 - Beta',

    # Indicate who your project is intended for
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',

    # Pick your license as you wish
    'License :: OSI Approved :: MIT License',

    # Specify the Python versions you support here. In particular, ensure
    # that you indicate whether you support Python 2, Python 3 or both.

    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.8'
  ],
)